.. _installation:

Installation
============

Installing SuperPandas
----------------------

You can install SuperPandas using pip:

.. code-block:: bash

   pip install superpandas

Alternatively, to install the latest development version directly from GitHub, use:

.. code-block:: bash

   pip install git+https://github.com/superpandas-ai/superpandas.git

Documentation Dependencies
--------------------------

To build the documentation locally, you will need to install the additional dependencies listed in the `requirements-docs.txt` file.

Navigate to the root directory of the project and run:

.. code-block:: bash

   pip install -r requirements-docs.txt
